<?php
/**
 * squared functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package squared
 */

if ( ! function_exists( 'squared_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function squared_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on squared, use a find and replace
		 * to change 'squared-viaductone' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'squared-viaductone', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'menu-1' => esc_html__( 'Primary', 'squared-viaductone' ),
		) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'squared_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support( 'custom-logo', array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
		) );
	}
endif;
add_action( 'after_setup_theme', 'squared_setup' );

function squared_editor_setup() {
    add_editor_style();
}
add_action( 'after_setup_theme', 'squared_editor_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function squared_content_width() {
	// This variable is intended to be overruled from themes.
	// Open WPCS issue: {@link https://github.com/WordPress-Coding-Standards/WordPress-Coding-Standards/issues/1043}.
	// phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedVariableFound
	$GLOBALS['content_width'] = apply_filters( 'squared_content_width', 640 );
}
add_action( 'after_setup_theme', 'squared_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function squared_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'squared-viaductone' ),
		'id'            => 'sidebar-1',
		'description'   => esc_html__( 'Add html widgets for squares grid.', 'squared-viaductone' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );




register_sidebar( array(
		'id'            => 'square01-title',
		'name'          => __( 'square01-title', 'squared-viaductone' ),
		'before_widget' => '<div class="card cardOne">   <div class="card-content" id="cardOne">',
		'after_widget'  => '  </div> </div>',
) );

register_sidebar( array(
	'id'            => 'square01-toggle-content',
	'name'          => __( 'square01-toggle-content', 'squared-viaductone' ),
	'before_widget' => '<div>',
	'after_widget'  => '</div>',
) );

register_sidebar( array(
		'id'            => 'square02-title',
		'name'          => __( 'square02-title', 'squared-viaductone' ),
		'before_widget' => '<div class="card cardTwo">   <div class="card-content" id="cardTwo">',
		'after_widget'  => '  </div> </div>',
) );

register_sidebar( array(
	'id'            => 'square02-toggle-content',
	'name'          => __( 'square02-toggle-content', 'squared-viaductone' ),
	'before_widget' => '<div>',
	'after_widget'  => '</div>',
) );

register_sidebar( array(
		'id'            => 'square03-title',
		'name'          => __( 'square03-title', 'squared-viaductone' ),
		'before_widget' => '<div class="card cardThree">   <div class="card-content" id="cardThree">',
		'after_widget'  => '  </div> </div>',
) );

register_sidebar( array(
	'id'            => 'square03-toggle-content',
	'name'          => __( 'square03-toggle-content', 'squared-viaductone' ),
	'before_widget' => '<div>',
	'after_widget'  => '</div>',
) );

register_sidebar( array(
		'id'            => 'square04-title',
		'name'          => __( 'square04-title', 'squared-viaductone' ),
		'before_widget' => '<div class="card cardFour">   <div class="card-content" id="cardFour">',
		'after_widget'  => '  </div> </div>',
) );

register_sidebar( array(
	'id'            => 'square04-toggle-content',
	'name'          => __( 'square04-toggle-content', 'squared-viaductone' ),
	'before_widget' => '<div>',
	'after_widget'  => '</div>',
) );




}
add_action( 'widgets_init', 'squared_widgets_init' );





/**
 * Enqueue scripts and styles.
 */
function squared_scripts() {
	wp_enqueue_style( 'squared-viaductone-style', get_stylesheet_uri() );

	wp_enqueue_style( 'squared-viaductone-fa', '//use.fontawesome.com/releases/v5.1.0/css/all.css' );

	wp_enqueue_script( 'squared-viaductone-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '20151215', true );

	wp_enqueue_script( 'squared-viaductone-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20151215', true );

	wp_enqueue_script( 'squared-viaductone-jQuery', get_template_directory_uri() . '/js/custom.js', array( 'jquery' ), '1.0.0', true );

	// wp_enqueue_script( 'squared-viaductone-parallaxJS', get_template_directory_uri() . '/js/parallaxJS/parallax.min.js', array( ), true );

	// wp_enqueue_style( 'squared-viaductone-google-fonts', '//fonts.googleapis.com/css?family=Source+Sans+Pro:100,300,400', array());

	wp_enqueue_style( 'squared-viaductone-typekit-fonts', '//fonts.googleapis.com/css?family=Didact+Gothic|Roboto+Mono:300" rel="stylesheet', array());


	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'squared_scripts' );




/**
 * Custom login
 */
function my_custom_login() {
		echo '<link rel="stylesheet" type="text/css" href="' . get_stylesheet_directory_uri() . '/login/custom-login-styles.css" />';
	}
add_action('login_head', 'my_custom_login');

function my_login_logo_url() {
    return home_url();
	}
add_filter( 'login_headerurl', 'my_login_logo_url' );

function my_login_logo_url_title() {
    return 'Your Site Name and Info';
}
add_filter( 'login_headertitle', 'my_login_logo_url_title' );





/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php';
}



/**
 * Load Theme Functions
 */
include_once get_template_directory() . '/inc/viaductone-category-widget.php';
include_once get_template_directory() . '/inc/viaductone-contact-form.php';
include_once get_template_directory() . '/inc/viaductone-pages-in-widgets.php';





/**
 * Allow logout without confirmation and send to home
 */
add_action('check_admin_referer', 'logout_without_confirm', 10, 2);
function logout_without_confirm($action, $result)
{

    if ($action == "log-out" && !isset($_GET['_wpnonce'])) {
        $redirect_to = isset($_REQUEST['redirect_to']) ? $_REQUEST['redirect_to'] : 'home';
        $location = str_replace('&amp;', '&', wp_logout_url($redirect_to));
        header("Location: $location");
        die;
    }
}



/**
 * Enable breadcrumbs on single posts
 */
 function the_breadcrumb() {
 		echo '<ul id="breadcrumbs">';

 		if (is_category() || is_single()) {
 			echo '<li>';
 			the_category(' </li><li> ');
 			if (is_single()) {
 				echo "</li><li>";
 				the_title();
 				echo '</li></ul>';
 			}
 		}
 	}



	/**
	 * Enable featured images as links
	 */
	function squared_autolink_featured_images( $html, $post_id, $post_image_id ) {
	$html = '<a href="' . get_permalink( $post_id ) . '" title="' . esc_attr( get_the_title( $post_id ) ) . '">' . $html . '</a>';
	return $html;
	}
	add_filter( 'post_thumbnail_html', 'squared_autolink_featured_images', 10, 3 );





/*********************************************
Customizer Options
***********************************************/

// add_action( 'send_headers', 'send_frame_options_header', 10, 0 );


function squared_customizer_head_styles() {

	/*********************************
	 Site-Title flex direction
	 *********************************/
	$site_title = get_theme_mod( 'squared_title_flex' );

	if ( $site_title != false ) :
	?>
		<style type="text/css">
			.site-branding {flex-direction: column;}
			.site-title,
			.site-description {margin: 0; width:100%;}
			.site-branding{width:100%;}
		</style>
	<?php
	endif;


	/*********************************
	Site Title and Tagline Color
	*********************************/
	$header_text_color = get_theme_mod( 'squared_header_text_color' );

	if ( $header_text_color != '#aaaaaa' ) :
	?>
		<style type="text/css">
			.site-title,
			.site-title a,
			.site-description {color: <?php echo $header_text_color; ?>;}
		</style>
	<?php
	endif;


	/*********************************
	Header Background Color
	*********************************/
	$header_background = get_theme_mod( 'squared_header_background' );

	if ( $header_background != '#26303c' ) :
	?>
		<style type="text/css">
			.site-header {background-color: <?php echo $header_background; ?>; }
		</style>

	<?php
	endif;


	/*********************************
	Menu Text Toggle
	*********************************/
	$menu_text_toggle = get_theme_mod( 'squared_menu_text_toggle' );

	if ( $menu_text_toggle != false ) :
	?>
		<style type="text/css">
		@media screen and (min-width: 37.5em) {
			.main-navigation li {position: relative;}
			.main-navigation a {position: absolute;text-decoration: none;z-index: 100;padding: 1em;left: 50%;-webkit-transform: translateX(-50%);transform: translateX(-50%);	font-size: .75em;visibility: hidden; margin: 0;}
			.menu-item:hover a {text-decoration: none;visibility: visible;}
			.menu-item {font-size: 1.5em;}
			.menu-item:hover {visibility: hidden;}
		}
		</style>
	<?php
	endif;


	/*********************************
	Link Color
	*********************************/
	$link_color = get_theme_mod( 'link_color' );

	if ( $link_color != '#aaaaaa' ) :
	?>
		<style type="text/css">
			a,
			.menu-item,
			.menu-item a {color: <?php echo $link_color; ?>;outline: 0;}
		</style>
	<?php
	endif;


	/*********************************
	Link Hover Color
	*********************************/
	$link_hover = get_theme_mod( 'squared_link_hover' );

	if ( $link_hover != '#efefef' ) :
	?>
		<style type="text/css">
			a:hover,
			.menu-item:hover,
			.menu-item:hover a {color: <?php echo $link_hover; ?>;outline: 0;}
		</style>
	<?php
	endif;


	/*********************************
	Primary Background Color
	*********************************/
	$background_color = get_theme_mod( 'squared_background_color' );

	if ( $background_color != '#26303c' ) :
	?>
		<style type="text/css">
			body,
			.toggle, privacy-toggle {background-color: <?php echo $background_color; ?>;}
		</style>
	<?php
	endif;


	/*********************************
	Primary Text Color
	*********************************/
	$body_text = get_theme_mod( 'squared_body_text_color' );

	if ( $body_text != '#aaaaaa' ) :
	?>
		<style type="text/css">
			body {color: <?php echo $body_text; ?>;}
		</style>
	<?php
	endif;


	/*********************************
	Secondary Background Color
	*********************************/
	$secondary_color = get_theme_mod( 'squared_secondary_color' );

	if ( $secondary_color != '#cccccc' ) :
	?>
		<style type="text/css">
		.category-content,
		.post-content,
		.entry-content,
		.post {background-color: <?php echo $secondary_color; ?>;}
		</style>
	<?php
	endif;


	/*********************************
	Secondary Text Color
	*********************************/
	$secondary_text = get_theme_mod( 'squared_secondary_text_color' );

	if ( $secondary_text != '#222222' ) :
	?>
		<style type="text/css">
			body {color: <?php echo $secondary_text; ?>;}
		</style>
	<?php
	endif;


	/*********************************
	Grid Icons Color
	*********************************/
	$grid_color = get_theme_mod( 'squared_grid_text' );

	if ( $grid_color != '#aaaaaa' ) :
	?>
		<style type="text/css">
			.card {
				color: <?php echo $grid_color; ?>;}
		</style>
	<?php
	endif;


	/*********************************
	Grid Icons Hover
	*********************************/
	$grid_hover = get_theme_mod( 'squared_grid_hover' );

	if ( $grid_hover != '#efefef' ) :
	?>
		<style type="text/css">
		.card:hover,
		.card:hover .widgettitle {color: <?php echo $grid_hover; ?>;}
		</style>
	<?php
	endif;


	/*********************************
	Grid Title Toggle
	*********************************/
	$grid_text = get_theme_mod( 'squared_grid_text_toggle' );

	if ( $grid_text != false ) :
	?>
			<style type="text/css">
			.widgettitle {visibility: hidden;}
		</style>
	<?php
	endif;


}
add_action( 'wp_head', 'squared_customizer_head_styles' );



/****************************************************
Custom Dashboard Widgets
****************************************************/

/**********Theme support widget***************/
add_action('wp_dashboard_setup', 'squared_dashboard_widgets');

function squared_dashboard_widgets() {
	global $wp_meta_boxes;
	wp_add_dashboard_widget('custom_help_widget', 'Theme Support', 'custom_dashboard_help');
}

function custom_dashboard_help() {
	echo '<p>Welcome to the squared Theme! Check the <a target="_blank" href="https://viaduct.one/squared/documentation">documentation </a> for instructions on how to install the demo content and set up your theme. Contact the developer <a target="_blank" href="https://viaduct.one/support">here</a>.</p>';
}
