<?php
/*
Plugin Name: viaductone Category Widget
Plugin URI: http://viaduct.one
Description: category in Widgets
Version: 1.0
Author: AWZR
Author URI: http://viaduct.one
*/

/*********************************************
Categories Widget
***********************************************/



	 if ( ! defined( 'ABSPATH' ) ) {
 		exit;
 	}

 	add_action( 'widgets_init', 'categorywidget' );
 	function categorywidget() {
 		register_widget( 'categorywidget' );
 	}

	 class categorywidget extends WP_Widget {
	 	const BASE_ID = 'categorywidget';
	 	const CLASS_NAME = 'categorywidget';
	 	const DISPLAY_NAME = 'Category Posts';
	 	const TEXT_DOMAIN = 'categorywidget';
	 	const VERSION = '3.3p-a8c1';

	 	function __construct() {
	 		$arguments = array(
	 			'classname' => self::CLASS_NAME,
	 			'description' => esc_html__( 'Configurably display posts via category.', 'squared-viaductone' ),
	 		);

	 		parent::__construct(
	 			self::BASE_ID,
	 			self::DISPLAY_NAME,
	 			$arguments
	 		);
	 	}

	 	/**
	 	 * Displays category posts widget on blog.
	 	 */
	 	function widget( $args, $instance ) {
	 		global $post;
	 		$post_old = $post; // Save the post object.


	 		// avoid PHP notices
	 		$title = isset( $instance[ 'title'] ) ? $instance[ 'title'] : '';
	 		$cat = isset( $instance[ 'cat' ] ) ? $instance[ 'cat' ] : false;
	 		$num = isset( $instance[ 'num' ] ) ? $instance[ 'num' ] : 0;
	 		$sort_by = isset( $instance[ 'sort_by' ] ) ? $instance[ 'sort_by' ] : null;
	 		$asc_sort_order = isset( $instance[ 'asc_sort_order' ] ) ? $instance[ 'asc_sort_order' ] : null;

	 		$before_widget = isset( $args['before_widget'] ) ? $args['before_widget'] : '';
	 		$before_title = isset( $args['before_title'] ) ? $args['before_title'] : '';
	 		$after_title = isset( $args['after_title'] ) ? $args['after_title'] : '';
	 		$after_widget = isset( $args['after_widget'] ) ? $args['after_widget'] : '';

	 		// If not title, use the name of the category.
	 		if( ! $title ) {
	 			$category_info = get_category( $cat );
	 			$title = $category_info->name;
	 		}

	 		$valid_sort_orders = array(
	 			'date',
	 			'title',
	 		);

	 		if ( in_array( $sort_by, $valid_sort_orders ) ) {
	 			$sort_order = $asc_sort_order ? 'ASC' : 'DESC';
	 		} else {
	 			// by default, display latest first
	 			$sort_by = 'date';
	 			$sort_order = 'DESC';
	 		}

	 		$arg_string = 'showposts=' . $num .
	 			'&cat=' . $cat .
	 			'&orderby=' . $sort_by .
	 			'&order=' . $sort_order;

	 		$use_cache = apply_filters( 'category_posts_widget_use_cache', true );
	 		if ( $use_cache ) {
	 			$cache_key = self::get_cache_key();
	 			$cached_widget_contents = wp_cache_get( $cache_key, 'widget' );
	 			if ( ! empty( $cached_widget_contents ) ) {

	 				// Cache Hit!  Print the cached contents and clean up
	 				echo wp_kses_post( $cached_widget_contents );
	 				$post = $post_old;
	 				return;
	 			}
	 		}

	 		// Cache miss. Build the content of the widget.

	 		$output = '';

	 		// Get array of post info.
	 		$cat_posts = new WP_Query( $arg_string );

	 		// Excerpt length filter


	 		$output .= wp_kses_post( $before_widget );

	 		// Widget title
	 		$output .= wp_kses_post( $before_title );

	 			$output .= esc_html( $title );


	 		$output .= wp_kses_post( $after_title );

	 		// Post list
	 		$output .= '<div class="post-list">';

	 		while ( $cat_posts->have_posts() ) {
	 			$cat_posts->the_post();
	 			$output .= '<div class="cat-post-item"><h2 class="post-title"> <a href="' . esc_url( get_the_permalink() ) .
	 					'" rel="bookmark" title="Permanent link to ' . esc_html( the_title_attribute( 'echo=0' ) ) . '">' . esc_html( get_the_title() ) . '</a></h2><div class="post-content"><div class="post-thumbnail">' . get_the_post_thumbnail() . '</div>' . get_the_content();


	 			$output .= '</div></div>';
	 		}

	 		$output .= '</div>';

	 		$output .= wp_kses_post( $after_widget );


	 		$post = $post_old; // Restore the post object.

	 		$output = wp_kses_post( $output );
	 		echo $output;

	 		$save_cache = apply_filters( 'category_posts_widget_save_cache', $use_cache );
	 		if ( $save_cache ) {
	 			if ( empty( $cache_key ) ) {
	 				$cache_key = self::get_cache_key();
	 			}

	 			$save_blocked = wp_cache_get( $cache_key . '-save_blocked', 'widget' );
	 			if ( $save_blocked ) {
	 				return;
	 			}

	 			// Max is limited by the liftetime of the nonce in get_cache_key
	 			$cache_expires = apply_filters( 'category_posts_widget_cache_expires', 30 * MINUTE_IN_SECONDS );

	 			wp_cache_set( $cache_key, $output, 'widget', $cache_expires );
	 		}
	 	}

	 	/**
	 	 * Form processing... Dead simple.
	 	 */
	 	function update( $new_instance, $old_instance ) {
	 		/**
	 		 * Save the thumbnail dimensions outside so we can
	 		 * register the sizes easily. We have to do this
	 		 * because the sizes must be registered beforehand
	 		 * in order for WP to hard crop images (this in
	 		 * turn is because WP only hard crops on upload).
	 		 * The code inside the widget is executed only when
	 		 * the widget is shown so we register the sizes
	 		 * outside of the widget class.
	 		 */



	 		return $new_instance;
	 	}

	 	/**
	 	 * The configuration form.
	 	 */
	 	function form( $instance ) {
	 		// avoid PHP notices
	 		$title = isset( $instance[ 'title'] ) ? $instance[ 'title'] : '';
	 		$cat = isset( $instance[ 'cat' ] ) ? $instance[ 'cat' ] : false;
	 		$num = isset( $instance[ 'num' ] ) ? $instance[ 'num' ] : 0;
	 		$sort_by = isset( $instance[ 'sort_by' ] ) ? $instance[ 'sort_by' ] : null;
	 		$asc_sort_order = isset( $instance[ 'asc_sort_order' ] ) ? $instance[ 'asc_sort_order' ] : null;

	 	?>
	 	<p>
	 	<label for="<?php
	 		echo esc_attr( $this->get_field_id("title") );
	 		?>"><?php esc_html_e( 'Title:', 'squared-viaductone' ); ?>
	 		<input class="widefat" id="<?php
	 			echo esc_attr( $this->get_field_id( 'title' ) );
	 		?>" name="<?php
	 			echo esc_attr( $this->get_field_name( 'title' ) );
	 		?>" type="text" value="<?php
	 			echo esc_attr( $title );
	 		?>" />
	 	</label>
	 	</p>

	 	<p>
	 	<label>
	 		<?php esc_html_e( 'Category:', 'squared-viaductone' ); ?>
	 		<?php wp_dropdown_categories(
	 			array(
	 				'name' => esc_attr( $this->get_field_name( 'cat' ) ),
	 				'selected' => (int) $cat,
	 			)
	 		); ?>
	 	</label>
	 	</p>

	 	<p>
	 	<label for="<?php echo esc_attr( $this->get_field_id( 'num' ) ); ?>">
	 		<?php esc_html_e( 'Number of posts to show', 'squared-viaductone' ); ?>:
	 		<input type="number" min="1" style="text-align: center; width: 20%; margin-left: 5px" id="<?php
	 			echo esc_attr( $this->get_field_id( 'num' ) );
	 		?>" name="<?php
	 			echo esc_attr( $this->get_field_name( 'num' ) );
	 		?>" type="text" value="<?php
	 			echo absint( $num );
	 		?>" size='3' />
	 	</label>
	 	</p>

	 	<p>
	 	<label for="<?php
	 		echo esc_attr( $this->get_field_id( 'sort_by' ) );
	 	?>">
	 	<?php esc_html_e( 'Sort by', 'squared-viaductone' ); ?>:
	 	<select id="<?php
	 	echo esc_attr( $this->get_field_id("sort_by") );
	 	?>" name="<?php
	 	echo esc_attr( $this->get_field_name("sort_by") );
	 	?>">
	 	<option value="date"<?php selected( $sort_by, "date" ); ?>><?php
	 		esc_html_e( 'Date', 'squared-viaductone' );
	 	?></option>
	 	<option value="title"<?php selected( $sort_by, "title" ); ?>><?php
	 		esc_html_e( 'Title', 'squared-viaductone' );
	 	?></option>
	 	<option value="comment_count"<?php selected( $sort_by, "comment_count" ); ?>><?php
	 		esc_html_e( 'Number of comments', 'squared-viaductone' );
	 	?></option>
	 	<option value="rand"<?php selected( $sort_by, "rand" ); ?>><?php
	 		esc_html_e( 'Random', 'squared-viaductone' );
	 	?></option>
	 	</select>
	 	</label>
	 	</p>

	 	<p>
	 	<label for="<?php
	 		echo esc_attr( $this->get_field_id("asc_sort_order") );
	 	?>">
	 	<input type="checkbox" class="checkbox"
	 	id="<?php
	 		echo esc_attr( $this->get_field_id("asc_sort_order") );
	 	?>"
	 	name="<?php
	 		echo esc_attr( $this->get_field_name("asc_sort_order") );
	 	?>"
	 		<?php checked( (bool) $asc_sort_order, true ); ?> />
	 		<?php esc_html_e( 'Reverse sort order (ascending)', 'squared-viaductone' ); ?>
	 	</label>
	 	</p>




	 	<?php
	 	}

	 	function flush_cache() {
	 		$use_cache = apply_filters( 'category_posts_widget_use_cache', true );
	 		if ( ! $use_cache ) {
	 			return;
	 		}

	 		$cache_key = self::get_cache_key();

	 		// Block updating the cache for an arbitrary amount of time to give the delete opportunity to propagate
	 		$block_save_cache_seconds = (int) apply_filters( 'category_posts_widget_block_save_cache_seconds', 10 );
	 		if ( $block_save_cache_seconds > 0 ) {
	 			wp_cache_set( $cache_key . '-save_blocked', 1, 'widget', $block_save_cache_seconds );
	 		}

	 		wp_cache_delete( $cache_key, 'widget' );
	 	}



	 	static function get_cache_key() {
	 		$key = 'category_posts_widget-' . self::VERSION . '-' . get_current_blog_id() . '-';
	 		$key .= wp_create_nonce( $key );
	 		return $key;
	 	}

	 	static function widgets_init() {
	 		return register_widget( 'categorywidget' );
	 	}

	 }

	 add_action( 'widgets_init', array( 'categorywidget', 'widgets_init' ) );

	 // Invalidate our cache on certain events
	 $flush_cache_callable = array( 'categorywidget', 'flush_cache' );
	 $update_option_action = 'update_option_widget_' . categorywidget::BASE_ID;
	 add_action( 'edit_post',                             $flush_cache_callable );
	 add_action( 'deleted_post',                          $flush_cache_callable );
	 add_action( 'deleted_comment',                       $flush_cache_callable );
	 add_action( $update_option_action,                   $flush_cache_callable );

/*********************************************
End of Categories Widget
***********************************************/

?>
